@@ -4,23 +4,24 @@ replacement.
 
 """
 
-
 import calendar
 import re
 import sys
 from datetime import date
 from datetime import datetime as dt_datetime
 from datetime import time as dt_time
-from datetime import timedelta
+from datetime import timedelta, timezone
 from datetime import tzinfo as dt_tzinfo
 from math import trunc
 from time import struct_time
 from typing import (
     Any,
     ClassVar,
+    Final,
     Generator,
     Iterable,
     List,
+    Literal,
     Mapping,
     Optional,
     Tuple,
@@ -36,12 +37,6 @@ from arrow import formatter, locales, parser, util
 from arrow.constants import DEFAULT_LOCALE, DEHUMANIZE_LOCALES
 from arrow.locales import TimeFrameLiteral
 
-if sys.version_info < (3, 8):  # pragma: no cover
-    from typing_extensions import Final, Literal
-else:
-    from typing import Final, Literal  # pragma: no cover
-
-
 TZ_EXPR = Union[dt_tzinfo, str]
 
 _T_FRAMES = Literal[
@@ -75,6 +70,7 @@ _GRANULARITY = Literal[
     "day",
     "week",
     "month",
+    "quarter",
     "year",
 ]
 
@@ -127,11 +123,13 @@ class Arrow:
     ]
     _ATTRS_PLURAL: Final[List[str]] = [f"{a}s" for a in _ATTRS]
     _MONTHS_PER_QUARTER: Final[int] = 3
+    _MONTHS_PER_YEAR: Final[int] = 12
     _SECS_PER_MINUTE: Final[int] = 60
     _SECS_PER_HOUR: Final[int] = 60 * 60
     _SECS_PER_DAY: Final[int] = 60 * 60 * 24
     _SECS_PER_WEEK: Final[int] = 60 * 60 * 24 * 7
     _SECS_PER_MONTH: Final[float] = 60 * 60 * 24 * 30.5
+    _SECS_PER_QUARTER: Final[float] = 60 * 60 * 24 * 30.5 * 3
     _SECS_PER_YEAR: Final[int] = 60 * 60 * 24 * 365
 
     _SECS_MAP: Final[Mapping[TimeFrameLiteral, float]] = {
@@ -141,6 +139,7 @@ class Arrow:
         "day": _SECS_PER_DAY,
         "week": _SECS_PER_WEEK,
         "month": _SECS_PER_MONTH,
+        "quarter": _SECS_PER_QUARTER,
         "year": _SECS_PER_YEAR,
     }
 
@@ -159,15 +158,15 @@ class Arrow:
         **kwargs: Any,
     ) -> None:
         if tzinfo is None:
-            tzinfo = dateutil_tz.tzutc()
+            tzinfo = timezone.utc
         # detect that tzinfo is a pytz object (issue #626)
         elif (
             isinstance(tzinfo, dt_tzinfo)
             and hasattr(tzinfo, "localize")
             and hasattr(tzinfo, "zone")
-            and tzinfo.zone  # type: ignore[attr-defined]
+            and tzinfo.zone
         ):
-            tzinfo = parser.TzinfoParser.parse(tzinfo.zone)  # type: ignore[attr-defined]
+            tzinfo = parser.TzinfoParser.parse(tzinfo.zone)
         elif isinstance(tzinfo, str):
             tzinfo = parser.TzinfoParser.parse(tzinfo)
 
@@ -194,7 +193,7 @@ class Arrow:
         """
 
         if tzinfo is None:
-            tzinfo = dateutil_tz.tzlocal()
+            tzinfo = dt_datetime.now().astimezone().tzinfo
 
         dt = dt_datetime.now(tzinfo)
 
@@ -222,7 +221,7 @@ class Arrow:
 
         """
 
-        dt = dt_datetime.now(dateutil_tz.tzutc())
+        dt = dt_datetime.now(timezone.utc)
 
         return cls(
             dt.year,
@@ -251,7 +250,7 @@ class Arrow:
         """
 
         if tzinfo is None:
-            tzinfo = dateutil_tz.tzlocal()
+            tzinfo = dt_datetime.now().astimezone().tzinfo
         elif isinstance(tzinfo, str):
             tzinfo = parser.TzinfoParser.parse(tzinfo)
 
@@ -285,7 +284,7 @@ class Arrow:
             raise ValueError(f"The provided timestamp {timestamp!r} is invalid.")
 
         timestamp = util.normalize_timestamp(float(timestamp))
-        dt = dt_datetime.utcfromtimestamp(timestamp)
+        dt = dt_datetime.fromtimestamp(timestamp, timezone.utc)
 
         return cls(
             dt.year,
@@ -295,7 +294,7 @@ class Arrow:
             dt.minute,
             dt.second,
             dt.microsecond,
-            dateutil_tz.tzutc(),
+            timezone.utc,
             fold=getattr(dt, "fold", 0),
         )
 
@@ -319,7 +318,7 @@ class Arrow:
 
         if tzinfo is None:
             if dt.tzinfo is None:
-                tzinfo = dateutil_tz.tzutc()
+                tzinfo = timezone.utc
             else:
                 tzinfo = dt.tzinfo
 
@@ -346,7 +345,7 @@ class Arrow:
         """
 
         if tzinfo is None:
-            tzinfo = dateutil_tz.tzutc()
+            tzinfo = timezone.utc
 
         return cls(date.year, date.month, date.day, tzinfo=tzinfo)
 
@@ -492,8 +491,8 @@ class Arrow:
             yield current
 
             values = [getattr(current, f) for f in cls._ATTRS]
-            current = cls(*values, tzinfo=tzinfo).shift(  # type: ignore
-                **{frame_relative: relative_steps}
+            current = cls(*values, tzinfo=tzinfo).shift(  # type: ignore[misc]
+                check_imaginary=True, **{frame_relative: relative_steps}
             )
 
             if frame in ["month", "quarter", "year"] and current.day < original_day:
@@ -551,14 +550,14 @@ class Arrow:
             (<Arrow [2021-02-20T00:00:00+00:00]>, <Arrow [2021-02-26T23:59:59.999999+00:00]>)
 
         """
-        if not 1 <= week_start <= 7:
-            raise ValueError("week_start argument must be between 1 and 7.")
 
         util.validate_bounds(bounds)
 
         frame_absolute, frame_relative, relative_steps = self._get_frames(frame)
 
         if frame_absolute == "week":
+            if not 1 <= week_start <= 7:
+                raise ValueError("week_start argument must be between 1 and 7.")
             attr = "day"
         elif frame_absolute == "quarter":
             attr = "month"
@@ -575,7 +574,7 @@ class Arrow:
             for _ in range(3 - len(values)):
                 values.append(1)
 
-            floor = self.__class__(*values, tzinfo=self.tzinfo)  # type: ignore
+            floor = self.__class__(*values, tzinfo=self.tzinfo)  # type: ignore[misc]
 
             if frame_absolute == "week":
                 # if week_start is greater than self.isoweekday() go back one week by setting delta = 7
@@ -584,7 +583,9 @@ class Arrow:
             elif frame_absolute == "quarter":
                 floor = floor.shift(months=-((self.month - 1) % 3))
 
-        ceil = floor.shift(**{frame_relative: count * relative_steps})
+        ceil = floor.shift(
+            check_imaginary=True, **{frame_relative: count * relative_steps}
+        )
 
         if bounds[0] == "(":
             floor = floor.shift(microseconds=+1)
@@ -594,39 +595,49 @@ class Arrow:
 
         return floor, ceil
 
-    def floor(self, frame: _T_FRAMES) -> "Arrow":
+    def floor(self, frame: _T_FRAMES, **kwargs: Any) -> "Arrow":
         """Returns a new :class:`Arrow <arrow.arrow.Arrow>` object, representing the "floor"
         of the timespan of the :class:`Arrow <arrow.arrow.Arrow>` object in a given timeframe.
         Equivalent to the first element in the 2-tuple returned by
         :func:`span <arrow.arrow.Arrow.span>`.
 
         :param frame: the timeframe.  Can be any ``datetime`` property (day, hour, minute...).
+        :param week_start: (optional) only used in combination with the week timeframe. Follows isoweekday() where
+            Monday is 1 and Sunday is 7.
 
         Usage::
 
             >>> arrow.utcnow().floor('hour')
             <Arrow [2013-05-09T03:00:00+00:00]>
 
+            >>> arrow.utcnow().floor('week', week_start=7)
+            <Arrow [2021-02-21T00:00:00+00:00]>
+
         """
 
-        return self.span(frame)[0]
+        return self.span(frame, **kwargs)[0]
 
-    def ceil(self, frame: _T_FRAMES) -> "Arrow":
+    def ceil(self, frame: _T_FRAMES, **kwargs: Any) -> "Arrow":
         """Returns a new :class:`Arrow <arrow.arrow.Arrow>` object, representing the "ceiling"
         of the timespan of the :class:`Arrow <arrow.arrow.Arrow>` object in a given timeframe.
         Equivalent to the second element in the 2-tuple returned by
         :func:`span <arrow.arrow.Arrow.span>`.
 
         :param frame: the timeframe.  Can be any ``datetime`` property (day, hour, minute...).
+        :param week_start: (optional) only used in combination with the week timeframe. Follows isoweekday() where
+            Monday is 1 and Sunday is 7.
 
         Usage::
 
             >>> arrow.utcnow().ceil('hour')
             <Arrow [2013-05-09T03:59:59.999999+00:00]>
 
+            >>> arrow.utcnow().ceil('week', week_start=7)
+            <Arrow [2021-02-27T23:59:59.999999+00:00]>
+
         """
 
-        return self.span(frame)[1]
+        return self.span(frame, **kwargs)[1]
 
     @classmethod
     def span_range(
@@ -756,7 +767,7 @@ class Arrow:
             >>> start = datetime(2013, 5, 5, 12, 30)
             >>> end = datetime(2013, 5, 5, 17, 15)
             >>> for r in arrow.Arrow.interval('hour', start, end, 2):
-            ...     print r
+            ...     print(r)
             ...
             (<Arrow [2013-05-05T12:00:00+00:00]>, <Arrow [2013-05-05T13:59:59.999999+00:00]>)
             (<Arrow [2013-05-05T14:00:00+00:00]>, <Arrow [2013-05-05T15:59:59.999999+00:00]>)
@@ -789,7 +800,6 @@ class Arrow:
         return self._datetime.isoformat()
 
     def __format__(self, formatstr: str) -> str:
-
         if len(formatstr) > 0:
             return self.format(formatstr)
 
@@ -800,8 +810,7 @@ class Arrow:
 
     # attributes and properties
 
-    def __getattr__(self, name: str) -> int:
-
+    def __getattr__(self, name: str) -> Any:
         if name == "week":
             return self.isocalendar()[1]
 
@@ -809,7 +818,7 @@ class Arrow:
             return int((self.month - 1) / self._MONTHS_PER_QUARTER) + 1
 
         if not name.startswith("_"):
-            value: Optional[int] = getattr(self._datetime, name, None)
+            value: Optional[Any] = getattr(self._datetime, name, None)
 
             if value is not None:
                 return value
@@ -962,7 +971,6 @@ class Arrow:
         absolute_kwargs = {}
 
         for key, value in kwargs.items():
-
             if key in self._ATTRS:
                 absolute_kwargs[key] = value
             elif key in ["week", "quarter"]:
@@ -985,10 +993,15 @@ class Arrow:
 
         return self.fromdatetime(current)
 
-    def shift(self, **kwargs: Any) -> "Arrow":
+    def shift(self, check_imaginary: bool = True, **kwargs: Any) -> "Arrow":
         """Returns a new :class:`Arrow <arrow.arrow.Arrow>` object with attributes updated
         according to inputs.
 
+        Parameters:
+        check_imaginary (bool): If True (default), will check for and resolve
+        imaginary times (like during DST transitions). If False, skips this check.
+
+
         Use pluralized property names to relatively shift their current value:
 
         >>> import arrow
@@ -1019,7 +1032,6 @@ class Arrow:
         additional_attrs = ["weeks", "quarters", "weekday"]
 
         for key, value in kwargs.items():
-
             if key in self._ATTRS_PLURAL or key in additional_attrs:
                 relative_kwargs[key] = value
             else:
@@ -1036,7 +1048,8 @@ class Arrow:
 
         current = self._datetime + relativedelta(**relative_kwargs)
 
-        if not dateutil_tz.datetime_exists(current):
+        # If check_imaginary is True, perform the check for imaginary times (DST transitions)
+        if check_imaginary and not dateutil_tz.datetime_exists(current):
             current = dateutil_tz.resolve_imaginary(current)
 
         return self.fromdatetime(current)
@@ -1093,7 +1106,8 @@ class Arrow:
         self, fmt: str = "YYYY-MM-DD HH:mm:ssZZ", locale: str = DEFAULT_LOCALE
     ) -> str:
         """Returns a string representation of the :class:`Arrow <arrow.arrow.Arrow>` object,
-        formatted according to the provided format string.
+        formatted according to the provided format string. For a list of formatting values,
+        see :ref:`supported-tokens`
 
         :param fmt: the format string.
         :param locale: the locale to format.
@@ -1148,7 +1162,7 @@ class Arrow:
         locale = locales.get_locale(locale)
 
         if other is None:
-            utc = dt_datetime.utcnow().replace(tzinfo=dateutil_tz.tzutc())
+            utc = dt_datetime.now(timezone.utc).replace(tzinfo=timezone.utc)
             dt = utc.astimezone(self._datetime.tzinfo)
 
         elif isinstance(other, Arrow):
@@ -1186,6 +1200,7 @@ class Arrow:
 
                 elif diff < self._SECS_PER_MINUTE * 2:
                     return locale.describe("minute", sign, only_distance=only_distance)
+
                 elif diff < self._SECS_PER_HOUR:
                     minutes = sign * max(delta_second // self._SECS_PER_MINUTE, 2)
                     return locale.describe(
@@ -1194,36 +1209,54 @@ class Arrow:
 
                 elif diff < self._SECS_PER_HOUR * 2:
                     return locale.describe("hour", sign, only_distance=only_distance)
+
                 elif diff < self._SECS_PER_DAY:
                     hours = sign * max(delta_second // self._SECS_PER_HOUR, 2)
                     return locale.describe("hours", hours, only_distance=only_distance)
-                elif diff < self._SECS_PER_DAY * 2:
+
+                calendar_diff = (
+                    relativedelta(dt, self._datetime)
+                    if self._datetime < dt
+                    else relativedelta(self._datetime, dt)
+                )
+                calendar_months = (
+                    calendar_diff.years * self._MONTHS_PER_YEAR + calendar_diff.months
+                )
+
+                # For months, if more than 2 weeks, count as a full month
+                if calendar_diff.days > 14:
+                    calendar_months += 1
+
+                calendar_months = min(calendar_months, self._MONTHS_PER_YEAR)
+
+                if diff < self._SECS_PER_DAY * 2:
                     return locale.describe("day", sign, only_distance=only_distance)
+
                 elif diff < self._SECS_PER_WEEK:
                     days = sign * max(delta_second // self._SECS_PER_DAY, 2)
                     return locale.describe("days", days, only_distance=only_distance)
 
+                elif calendar_months >= 1 and diff < self._SECS_PER_YEAR:
+                    if calendar_months == 1:
+                        return locale.describe(
+                            "month", sign, only_distance=only_distance
+                        )
+                    else:
+                        months = sign * calendar_months
+                        return locale.describe(
+                            "months", months, only_distance=only_distance
+                        )
+
                 elif diff < self._SECS_PER_WEEK * 2:
                     return locale.describe("week", sign, only_distance=only_distance)
+
                 elif diff < self._SECS_PER_MONTH:
                     weeks = sign * max(delta_second // self._SECS_PER_WEEK, 2)
                     return locale.describe("weeks", weeks, only_distance=only_distance)
 
-                elif diff < self._SECS_PER_MONTH * 2:
-                    return locale.describe("month", sign, only_distance=only_distance)
-                elif diff < self._SECS_PER_YEAR:
-                    # TODO revisit for humanization during leap years
-                    self_months = self._datetime.year * 12 + self._datetime.month
-                    other_months = dt.year * 12 + dt.month
-
-                    months = sign * max(abs(other_months - self_months), 2)
-
-                    return locale.describe(
-                        "months", months, only_distance=only_distance
-                    )
-
                 elif diff < self._SECS_PER_YEAR * 2:
                     return locale.describe("year", sign, only_distance=only_distance)
+
                 else:
                     years = sign * max(delta_second // self._SECS_PER_YEAR, 2)
                     return locale.describe("years", years, only_distance=only_distance)
@@ -1245,19 +1278,27 @@ class Arrow:
                     delta = sign * delta_second / self._SECS_PER_WEEK
                 elif granularity == "month":
                     delta = sign * delta_second / self._SECS_PER_MONTH
+                elif granularity == "quarter":
+                    delta = sign * delta_second / self._SECS_PER_QUARTER
                 elif granularity == "year":
                     delta = sign * delta_second / self._SECS_PER_YEAR
                 else:
                     raise ValueError(
                         "Invalid level of granularity. "
-                        "Please select between 'second', 'minute', 'hour', 'day', 'week', 'month' or 'year'."
+                        "Please select between 'second', 'minute', 'hour', 'day', 'week', 'month', 'quarter' or 'year'."
                     )
 
                 if trunc(abs(delta)) != 1:
-                    granularity += "s"  # type: ignore
+                    granularity += "s"  # type: ignore[assignment]
                 return locale.describe(granularity, delta, only_distance=only_distance)
 
             else:
+                if not granularity:
+                    raise ValueError(
+                        "Empty granularity list provided. "
+                        "Please select one or more from 'second', 'minute', 'hour', 'day', 'week', 'month', 'quarter', 'year'."
+                    )
+
                 timeframes: List[Tuple[TimeFrameLiteral, float]] = []
 
                 def gather_timeframes(_delta: float, _frame: TimeFrameLiteral) -> float:
@@ -1275,6 +1316,7 @@ class Arrow:
                 delta = float(delta_second)
                 frames: Tuple[TimeFrameLiteral, ...] = (
                     "year",
+                    "quarter",
                     "month",
                     "week",
                     "day",
@@ -1288,7 +1330,7 @@ class Arrow:
                 if len(timeframes) < len(granularity):
                     raise ValueError(
                         "Invalid level of granularity. "
-                        "Please select between 'second', 'minute', 'hour', 'day', 'week', 'month' or 'year'."
+                        "Please select between 'second', 'minute', 'hour', 'day', 'week', 'month', 'quarter' or 'year'."
                     )
 
                 return locale.describe_multi(timeframes, only_distance=only_distance)
@@ -1301,7 +1343,7 @@ class Arrow:
 
     def dehumanize(self, input_string: str, locale: str = "en_us") -> "Arrow":
         """Returns a new :class:`Arrow <arrow.arrow.Arrow>` object, that represents
-        the time difference relative to the attrbiutes of the
+        the time difference relative to the attributes of the
         :class:`Arrow <arrow.arrow.Arrow>` object.
 
         :param timestring: a ``str`` representing a humanized relative time.
@@ -1354,7 +1396,6 @@ class Arrow:
 
         # Search input string for each time unit within locale
         for unit, unit_object in locale_obj.timeframes.items():
-
             # Need to check the type of unit_object to create the correct dictionary
             if isinstance(unit_object, Mapping):
                 strings_to_search = unit_object
@@ -1365,13 +1406,12 @@ class Arrow:
             # Needs to cycle all through strings as some locales have strings that
             # could overlap in a regex match, since input validation isn't being performed.
             for time_delta, time_string in strings_to_search.items():
-
                 # Replace {0} with regex \d representing digits
                 search_string = str(time_string)
                 search_string = search_string.format(r"\d+")
 
                 # Create search pattern and find within string
-                pattern = re.compile(fr"{search_string}")
+                pattern = re.compile(rf"(^|\b|\d){search_string}")
                 match = pattern.search(input_string)
 
                 # If there is no match continue to next iteration
@@ -1406,19 +1446,19 @@ class Arrow:
         # Assert error if string does not modify any units
         if not any([True for k, v in unit_visited.items() if v]):
             raise ValueError(
-                "Input string not valid. Note: Some locales do not support the week granulairty in Arrow. "
+                "Input string not valid. Note: Some locales do not support the week granularity in Arrow. "
                 "If you are attempting to use the week granularity on an unsupported locale, this could be the cause of this error."
             )
 
         # Sign logic
         future_string = locale_obj.future
         future_string = future_string.format(".*")
-        future_pattern = re.compile(fr"^{future_string}$")
+        future_pattern = re.compile(rf"^{future_string}$")
         future_pattern_match = future_pattern.findall(input_string)
 
         past_string = locale_obj.past
         past_string = past_string.format(".*")
-        past_pattern = re.compile(fr"^{past_string}$")
+        past_pattern = re.compile(rf"^{past_string}$")
         past_pattern_match = past_pattern.findall(input_string)
 
         # If a string contains the now unit, there will be no relative units, hence the need to check if the now unit
@@ -1438,7 +1478,7 @@ class Arrow:
 
         time_changes = {k: sign_val * v for k, v in time_object_info.items()}
 
-        return current_time.shift(**time_changes)
+        return current_time.shift(check_imaginary=True, **time_changes)
 
     # query functions
 
@@ -1705,7 +1745,6 @@ class Arrow:
     # math
 
     def __add__(self, other: Any) -> "Arrow":
-
         if isinstance(other, (timedelta, relativedelta)):
             return self.fromdatetime(self._datetime + other, self._datetime.tzinfo)
 
@@ -1723,7 +1762,6 @@ class Arrow:
         pass  # pragma: no cover
 
     def __sub__(self, other: Any) -> Union[timedelta, "Arrow"]:
-
         if isinstance(other, (timedelta, relativedelta)):
             return self.fromdatetime(self._datetime - other, self._datetime.tzinfo)
 
@@ -1736,7 +1774,6 @@ class Arrow:
         return NotImplemented
 
     def __rsub__(self, other: Any) -> timedelta:
-
         if isinstance(other, dt_datetime):
             return other - self._datetime
 
@@ -1745,42 +1782,36 @@ class Arrow:
     # comparisons
 
     def __eq__(self, other: Any) -> bool:
-
         if not isinstance(other, (Arrow, dt_datetime)):
             return False
 
         return self._datetime == self._get_datetime(other)
 
     def __ne__(self, other: Any) -> bool:
-
         if not isinstance(other, (Arrow, dt_datetime)):
             return True
 
         return not self.__eq__(other)
 
     def __gt__(self, other: Any) -> bool:
-
         if not isinstance(other, (Arrow, dt_datetime)):
             return NotImplemented
 
         return self._datetime > self._get_datetime(other)
 
     def __ge__(self, other: Any) -> bool:
-
         if not isinstance(other, (Arrow, dt_datetime)):
             return NotImplemented
 
         return self._datetime >= self._get_datetime(other)
 
     def __lt__(self, other: Any) -> bool:
-
         if not isinstance(other, (Arrow, dt_datetime)):
             return NotImplemented
 
         return self._datetime < self._get_datetime(other)
 
     def __le__(self, other: Any) -> bool:
-
         if not isinstance(other, (Arrow, dt_datetime)):
             return NotImplemented
 
@@ -1791,7 +1822,7 @@ class Arrow:
     def _get_tzinfo(tz_expr: Optional[TZ_EXPR]) -> dt_tzinfo:
         """Get normalized tzinfo object from various inputs."""
         if tz_expr is None:
-            return dateutil_tz.tzutc()
+            return timezone.utc
         if isinstance(tz_expr, dt_tzinfo):
             return tz_expr
         else:
@@ -1852,7 +1883,6 @@ class Arrow:
     def _get_iteration_params(cls, end: Any, limit: Optional[int]) -> Tuple[Any, int]:
         """Sets default end and limit values for range method."""
         if end is None:
-
             if limit is None:
                 raise ValueError("One of 'end' or 'limit' is required.")
 
@@ -1866,7 +1896,7 @@ class Arrow:
     @staticmethod
     def _is_last_day_of_month(date: "Arrow") -> bool:
         """Returns a boolean indicating whether the datetime is the last day of the month."""
-        return date.day == calendar.monthrange(date.year, date.month)[1]
+        return cast(int, date.day) == calendar.monthrange(date.year, date.month)[1]
 
 
 Arrow.min = Arrow.fromdatetime(dt_datetime.min)
